@@ -4,6 +4,7 @@ Module for managing configuration data from `config.json`
 
 import os
 import json
+import numbers
 
 
 class SHConfig:
@@ -57,8 +58,8 @@ class SHConfig:
             'max_wfs_records_per_query': 100,
             'max_opensearch_records_per_query': 500,
             'max_download_attempts': 4,
-            'download_sleep_time': 5,
-            'download_timeout_seconds': 120,
+            'download_sleep_time': 5.0,
+            'download_timeout_seconds': 120.0,
             'number_of_download_processes': 1
         }
 
@@ -75,6 +76,8 @@ class SHConfig:
 
             for param, default_param in self.CONFIG_PARAMS.items():
                 param_type = type(default_param)
+                if (param_type is float) and isinstance(config[param], numbers.Number):
+                    continue
                 if not isinstance(config[param], param_type):
                     raise ValueError("Value of parameter '{}' must be of type {}".format(param, param_type.__name__))
 
@@ -259,8 +262,8 @@ class SHConfig:
         """
         return '{}/oauth/token'.format(self.sh_base_url)
 
-    def get_sh_processing_api_url(self):
-        """  Provides URL for Sentinel Hub processing API endpoint
+    def get_sh_process_api_url(self):
+        """  Provides URL for Sentinel Hub Process API endpoint
 
         :return: An URL endpoint
         :rtype: str
@@ -283,3 +286,13 @@ class SHConfig:
         :rtype: str
         """
         return '{}/aux/ratelimit'.format(self.sh_base_url)
+
+    def raise_for_missing_instance_id(self):
+        """ In case Sentinel Hub instance ID is missing it raises an informative error
+
+        :raises: ValueError
+        """
+        if not self.instance_id:
+            raise ValueError('Sentinel Hub instance ID is missing. '
+                             'Either provide it with SHConfig object or save it into config.json configuration file. '
+                             'Check http://sentinelhub-py.readthedocs.io/en/latest/configure.html for more info.')
