@@ -4,8 +4,8 @@ Module implementing geometry classes
 from abc import ABC, abstractmethod
 from math import ceil
 
-import shapely.ops
 import shapely.geometry
+import shapely.ops
 import shapely.wkt
 
 from .constants import CRS
@@ -191,6 +191,10 @@ class BBox(BaseGeometry):
     def transform(self, crs):
         """ Transforms BBox from current CRS to target CRS
 
+        This transformation will take lower left and upper right corners of the bounding box, transform these 2 points
+        and define a new bounding box with them. The resulting bounding box might not completely cover the original
+        bounding box but at least the transformation is reversible.
+
         :param crs: target CRS
         :type crs: constants.CRS
         :return: Bounding box in target CRS
@@ -200,6 +204,22 @@ class BBox(BaseGeometry):
         return BBox((transform_point(self.lower_left, self.crs, new_crs),
                      transform_point(self.upper_right, self.crs, new_crs)), crs=new_crs)
 
+    def transform_bounds(self, crs):
+        """ Alternative way to transform BBox from current CRS to target CRS.
+
+        This transformation will transform the bounding box geometry to another CRS as a geometric object, and then
+        define a new bounding box from boundaries of that geometry. The resulting bounding box might be larger than
+        original bounding box but it will always completely cover it.
+
+        :param crs: target CRS
+        :type crs: constants.CRS
+        :return: Bounding box in target CRS
+        :rtype: BBox
+        """
+        bbox_geometry = Geometry(self.geometry, self.crs)
+        bbox_geometry = bbox_geometry.transform(crs)
+        return bbox_geometry.bbox
+
     def buffer(self, buffer):
         """ Changes both BBox dimensions (width and height) by a percentage of size of each dimension. If number is
         negative, the size will decrease. Returns a new instance of BBox object.
@@ -328,7 +348,7 @@ class BBox(BaseGeometry):
         """
         if len(bbox) == 4:
             return tuple(map(float, bbox))
-        if len(bbox) == 2 and all([isinstance(point, (list, tuple)) for point in bbox]):
+        if len(bbox) == 2 and all(isinstance(point, (list, tuple)) for point in bbox):
             return BBox._tuple_from_list_or_tuple(bbox[0] + bbox[1])
         raise TypeError('Expected a valid list or tuple representation of a bbox')
 
@@ -339,7 +359,7 @@ class BBox(BaseGeometry):
         :param bbox: e.g. str of the form `min_x ,min_y  max_x, max_y`
         :return: tuple (min_x,min_y,max_x,max_y)
         """
-        return tuple([float(s) for s in bbox.replace(',', ' ').split() if s])
+        return tuple(float(s) for s in bbox.replace(',', ' ').split() if s)
 
     @staticmethod
     def _tuple_from_dict(bbox):
@@ -423,6 +443,25 @@ class Geometry(BaseGeometry):
 
         return Geometry(geometry, crs=new_crs)
 
+    @classmethod
+    def from_geojson(cls, geojson, crs=None):
+        """ Create Geometry object from geojson. It will parse crs from geojson (if info is available),
+        otherwise it will be set to crs (WGS84 if parameter is empty)
+
+        :param geojson: geojson geometry (single feature)
+        :param crs: crs to be used if not available in geojson, CRS.WGS84 if not provided
+        :return: Geometry object
+        """
+        try:
+            crs = CRS(geojson['crs']['properties']['name'])
+        except (KeyError, AttributeError, TypeError):
+            pass
+
+        if not crs:
+            crs = CRS.WGS84
+
+        return cls(geojson, crs=crs)
+
     @property
     def geometry(self):
         """ Returns shapely object representing geometry in this class
