@@ -1,4 +1,4 @@
-""" SentinelHubRequest for the Processing API
+""" SentinelHubRequest for the Process API
 
 Documentation: https://docs.sentinel-hub.com/api/latest/reference/
 """
@@ -7,7 +7,7 @@ from .data_collections import DataCollection, OrbitDirection, handle_deprecated_
 from .download import DownloadRequest, SentinelHubDownloadClient
 from .data_request import DataRequest
 from .geometry import Geometry, BBox
-from .time_utils import parse_time_interval
+from .time_utils import parse_time_interval, serialize_time
 
 
 class SentinelHubRequest(DataRequest):
@@ -17,7 +17,7 @@ class SentinelHubRequest(DataRequest):
                  **kwargs):
         """
         For details of certain parameters check the
-        `Processing API reference <https://docs.sentinel-hub.com/api/latest/reference/#operation/process>`_.
+        `Process API reference <https://docs.sentinel-hub.com/api/latest/reference/#operation/process>`_.
 
         :param evalscript: `Evalscript <https://docs.sentinel-hub.com/api/latest/#/Evalscript/>`_.
         :type evalscript: str
@@ -43,7 +43,8 @@ class SentinelHubRequest(DataRequest):
         if not isinstance(evalscript, str):
             raise ValueError("'evalscript' should be a string")
 
-        self.mime_type = MimeType.TAR if len(responses) > 1 else MimeType(responses[0]['format']['type'].split('/')[1])
+        parsed_mime_type = MimeType.from_string(responses[0]['format']['type'].split('/')[1])
+        self.mime_type = MimeType.TAR if len(responses) > 1 else parsed_mime_type
 
         self.payload = self.body(
             request_bounds=self.bounds(bbox=bbox, geometry=geometry),
@@ -73,9 +74,9 @@ class SentinelHubRequest(DataRequest):
     @staticmethod
     def input_data(data_collection=None, time_interval=None, maxcc=None, mosaicking_order=None, upsampling=None,
                    downsampling=None, other_args=None, data_source=None):
-        """ Generate the `input` part of the Processing API request body
+        """ Generate the `input` part of the Process API request body
 
-        :param data_collection: One of supported ProcessingAPI data collections.
+        :param data_collection: One of supported Process API data collections.
         :type data_collection: DataCollection
         :param time_interval: interval with start and end date of the form YYYY-MM-DDThh:mm:ss or YYYY-MM-DD
         :type time_interval: (str, str) or (datetime, datetime)
@@ -115,7 +116,7 @@ class SentinelHubRequest(DataRequest):
 
     @staticmethod
     def body(request_bounds, request_data, evalscript, request_output=None, other_args=None):
-        """ Generate the body the Processing API request body
+        """ Generate the body the Process API request body
 
         :param request_bounds: A dictionary as generated by `SentinelHubRequest.bounds` helper method.
         :type request_bounds: dict
@@ -147,7 +148,7 @@ class SentinelHubRequest(DataRequest):
 
     @staticmethod
     def output_response(identifier, response_format, other_args=None):
-        """ Generate an element of `output.responses` as described in the Processing API reference.
+        """ Generate an element of `output.responses` as described in the Process API reference.
 
         :param identifier: Identifier of the output response.
         :type identifier: str
@@ -171,7 +172,7 @@ class SentinelHubRequest(DataRequest):
 
     @staticmethod
     def output(responses, size=None, resolution=None, other_args=None):
-        """ Generate an `output` part of the request as described in the Processing API reference
+        """ Generate an `output` part of the request as described in the Process API reference
 
         :param responses: A list of objects in `output.responses` as generated by `SentinelHubRequest.output_response`.
         :type responses: List[dict]
@@ -202,7 +203,7 @@ class SentinelHubRequest(DataRequest):
 
     @staticmethod
     def bounds(bbox=None, geometry=None, other_args=None):
-        """ Generate a `bound` part of the Processing API request
+        """ Generate a `bound` part of the Process API request
 
         :param bbox: Bounding box describing the area of interest.
         :type bbox: sentinelhub.BBox
@@ -224,9 +225,6 @@ class SentinelHubRequest(DataRequest):
         if bbox and geometry and bbox.crs != geometry.crs:
             raise ValueError("bbox and geometry should be in the same CRS")
 
-        if bbox is None:
-            bbox = geometry.bbox
-
         crs = bbox.crs if bbox else geometry.crs
 
         request_bounds = {
@@ -283,14 +281,13 @@ class InputDataDict(dict):
 
 
 def _get_data_filters(data_collection, time_interval, maxcc, mosaicking_order):
-    """ Builds a dictionary of data filters for Processing API
+    """ Builds a dictionary of data filters for Process API
     """
     data_filter = {}
 
     if time_interval:
-        date_from, date_to = parse_time_interval(time_interval)
-        date_from, date_to = date_from + 'Z', date_to + 'Z'
-        data_filter['timeRange'] = {'from': date_from, 'to': date_to}
+        start_time, end_time = serialize_time(parse_time_interval(time_interval, allow_undefined=True), use_tz=True)
+        data_filter['timeRange'] = {'from': start_time, 'to': end_time}
 
     if maxcc is not None:
         if not isinstance(maxcc, float) and (maxcc < 0 or maxcc > 1):
@@ -314,7 +311,7 @@ def _get_data_filters(data_collection, time_interval, maxcc, mosaicking_order):
 
 
 def _get_data_collection_filters(data_collection):
-    """ Builds a dictionary of filters for Processing API from a data collection definition
+    """ Builds a dictionary of filters for Process API from a data collection definition
     """
     filters = {}
 
@@ -337,7 +334,7 @@ def _get_data_collection_filters(data_collection):
 
 
 def _get_processing_params(upsampling, downsampling):
-    """ Builds a dictionary of processing parameters for Processing API
+    """ Builds a dictionary of processing parameters for Process API
     """
     processing_params = {}
 
